__all__ = [
    "__version__",
    "__version_info__",
    "parse_gid",
    "parse_galleryinfo",
    "GalleryInfoParser",
]
__author__ = "Kuan-Lun Wang"

__version__ = "0.1.0"
__version_info__ = tuple(map(int, __version__.split(".")))


from .galleryinfo_parser import parse_gid, parse_galleryinfo, GalleryInfoParser
